==> dxde_1.40.6-1.tar.gz: BUILD/src/gui/dialogs/dphdruhydialog.cpp <==
/***************************************************************
 * Name:      dphdruhydialog.cpp
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2015
 * License:   GPL3
 **************************************************************/

#include "dphdruhydialog.h"
#include "dxdefs.h"
#include "utils/dxutils.h"
#include "utils/dxsettings.h"
#include "resources/images/checked.xpm"
#include "resources/images/unchecked.xpm"
#include "resources/images/asc.xpm"
#include "resources/images/desc.xpm"
#include "resources/images/filter.xpm"
#include "resources/images/filter_clear.xpm"

IMPLEMENT_DYNAMIC_CLASS(DphDruhyDialog, wxDialog)

BEGIN_EVENT_TABLE(DphDruhyDialog, wxDialog)
    EVT_BUTTON(wxID_OK, DphDruhyDialog::OnOk)
    EVT_BUTTON(wxID_CANCEL, DphDruhyDialog::OnCancel)
    EVT_LIST_ITEM_RIGHT_CLICK(ID_DPHDRUHY_LIST, DphDruhyDialog::OnItemRightClick)
    EVT_LIST_ITEM_ACTIVATED(ID_DPHDRUHY_LIST, DphDruhyDialog::OnItemActivated)
    EVT_LIST_ITEM_SELECTED(ID_DPHDRUHY_LIST, DphDruhyDialog::OnItemSelected)
    EVT_LIST_ITEM_DESELECTED(ID_DPHDRUHY_LIST, DphDruhyDialog::OnItemDeselected)
    EVT_LIST_COL_CLICK(ID_DPHDRUHY_LIST, DphDruhyDialog::OnColumnClick)
    EVT_MENU(ID_DPHDRUHY_ENABLE, DphDruhyDialog::OnEnableDphDruh)
    EVT_MENU(ID_DPHDRUHY_FILTER, DphDruhyDialog::OnFilter)
    EVT_MENU(ID_DPHDRUHY_FILTERCLEAR, DphDruhyDialog::OnFilterClear)
END_EVENT_TABLE()

DphDruhyDialog::DphDruhyDialog(wxWindow *parent, bool select, DType type, const wxDateTime &datum)
    : wxDialog(parent, wxID_ANY, wxString::FromUTF8("Členění DPH")),
      m_select(select), m_type(type), m_selectedId(-1), m_sortCol(0), m_sortAsc(true), m_filter(false)
{
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, 0));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, 1));

    if(select) m_datum = datum;
    else m_datum = dxsettings.datum();

    m_mainSizer = new wxBoxSizer(wxVERTICAL);
    if(!m_select)
    {
        m_bar = new wxToolBar(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTB_HORIZONTAL|wxTB_FLAT|wxTB_NODIVIDER);
        m_bar->AddTool(ID_DPHDRUHY_FILTER, wxEmptyString, wxBitmap(filter_xpm), dxutils::GreyScaledIcon(filter_xpm), wxITEM_CHECK, "Filtrovat");
        m_bar->AddTool(ID_DPHDRUHY_FILTERCLEAR, wxEmptyString, wxBitmap(filter_clear_xpm), dxutils::GreyScaledIcon(filter_clear_xpm), wxITEM_NORMAL, wxString::FromUTF8("Zrušit filtr"));
        m_bar->Realize();
        m_bar->EnableTool(ID_DPHDRUHY_FILTERCLEAR, false);
        m_mainSizer->Add(m_bar, 0, wxALL|wxEXPAND, 5);
    }
    wxSize imageSize(16, 16);
    m_imageList.reset(new wxImageList(imageSize.GetWidth(), imageSize.GetHeight()));
    m_imageList->Add(wxImage(checked_xpm).Scale(16, 16));
    m_imageList->Add(wxImage(unchecked_xpm).Scale(16, 16));
    m_imageList->Add(wxImage(asc_xpm).Scale(16, 16));
    m_imageList->Add(wxImage(desc_xpm).Scale(16, 16));
    m_list = new dxListCtrl(this, ID_DPHDRUHY_LIST, false);
    m_list->SetImageList(m_imageList.get(), wxIMAGE_LIST_SMALL);
    wxListItem col0;
    col0.SetId(0);
    col0.SetText("Zkratka");
    col0.SetWidth(65);
    m_list->InsertColumn(0, col0);
    wxListItem col1;
    col1.SetId(1);
    col1.SetText("Popis");
    col1.SetWidth(350);
    m_list->InsertColumn(1, col1);
    wxListItem col2;
    col2.SetId(2);
    col2.SetText(wxString::FromUTF8("Plnění"));
    col2.SetWidth(100);
    m_list->InsertColumn(2, col2);
    wxListItem col3;
    col3.SetId(3);
    col3.SetText(wxString::FromUTF8("Řádky v přiznání"));
    col3.SetWidth(115);
    m_list->InsertColumn(3, col3);
    wxListItem col4;
    col4.SetId(4);
    col4.SetText(wxString::FromUTF8("Předmět plnění"));
    col4.SetWidth(110);
    m_list->InsertColumn(4, col4);
    wxListItem col5;
    col5.SetId(5);
    col5.SetText(wxString::FromUTF8("Oddíl v KH"));
    col5.SetWidth(115);
    m_list->InsertColumn(5, col5);
    if(!m_select)
    {
        wxListItem col6;
        col6.SetId(6);
        col6.SetText(wxString::FromUTF8("Nabízet"));
        col6.SetWidth(80);
        m_list->InsertColumn(6, col6);
    }
    m_list->setResizeColumn(2);
    m_list->setResizeColumnMinWidth(100);
    fillList();
    m_mainSizer->Add(m_list, 1, wxALL|wxEXPAND, 5);
    wxStdDialogButtonSizer *btnSizer = new wxStdDialogButtonSizer();
    wxButton* okButton = new wxButton(this, wxID_OK, select? "&Vybrat" : "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(okButton);
    wxButton* cancelButton = new wxButton(this, wxID_CANCEL, "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(cancelButton);
    btnSizer->Realize();
    m_mainSizer->Add(btnSizer, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 5);
    this->SetSizer(m_mainSizer);
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

void DphDruhyDialog::OnOk(wxCommandEvent& /*event*/)
{
    EndModal(wxID_OK);
}

void DphDruhyDialog::OnCancel(wxCommandEvent& /*event*/)
{
    EndModal(wxID_CANCEL);
}

void DphDruhyDialog::OnItemRightClick(wxListEvent &event)
{
    setSelectedId(event.GetIndex());
    if(m_selectedId != -1)
    {
        wxMenu popup;
        popup.Append(ID_DPHDRUHY_ENABLE, m_dphdruhy[event.GetIndex()].nabizet()?wxString::FromUTF8("Nenabízet členění DPH"):wxString::FromUTF8("Nabízet členění DPH"));
        PopupMenu(&popup, event.GetPoint()+m_list->GetPosition());
    }
}

void DphDruhyDialog::OnItemActivated(wxListEvent &event)
{
    setSelectedId(event.GetIndex());
    if(m_select)
    {
        EndModal(wxID_OK);
    }
}

void DphDruhyDialog::OnItemSelected(wxListEvent &event)
{
    setSelectedId(event.GetIndex());
}

void DphDruhyDialog::OnItemDeselected(wxListEvent& /*event*/)
{
    setSelectedId(-1);
}

void DphDruhyDialog::setSelectedId(long selectedIndex)
{
    if(selectedIndex < 0)
        m_selectedId = -1;
    else
        m_selectedId = m_dphdruhy[selectedIndex].id();
}

void DphDruhyDialog::OnEnableDphDruh(wxCommandEvent& /*event*/)
{
    if(m_selectedId == -1) return;
    idbmodel->nabizetDphDruh(m_selectedId);
    fillList();
}

void DphDruhyDialog::fillList()
{
    m_list->DeleteAllItems();
    m_list->Hide();
    getData();
    idbmodel->sortDphDruh(m_dphdruhy, m_sortCol, m_sortAsc);
    for(size_t i=0; i < m_dphdruhy.GetCount(); i++)
    {
        if(!m_datum.IsBetween(m_dphdruhy[i].validFrom(), m_dphdruhy[i].validTo())) continue;
        wxListItem item;
        item.SetId(static_cast<long>(i));
        item.SetText(m_dphdruhy[i].zkratka());
        item.SetImage(-1);
        m_list->InsertItem(item);
        m_list->SetItem(static_cast<long>(i), 1, m_dphdruhy[i].popis());
        m_list->SetItem(static_cast<long>(i), 2, m_dphdruhy[i].plneni()?wxString::FromUTF8("Přijaté"):wxString::FromUTF8("Uskutečněné"));
        m_list->SetItem(static_cast<long>(i), 3, m_dphdruhy[i].radky());
        m_list->SetItem(static_cast<long>(i), 4, m_dphdruhy[i].kpp());
        m_list->SetItem(static_cast<long>(i), 5, m_dphdruhy[i].kh());
        if(!m_select) m_list->SetItem(static_cast<long>(i), 6, wxEmptyString, m_dphdruhy[i].nabizet()?0:1);
    }
    m_list->Show();
    if(m_select && m_dphdruhy.GetCount())
        m_list->SetItemState(0, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
    else
        setSelectedId(-1);
    setColumnImage(m_sortCol, m_sortAsc?2:3);
}

void DphDruhyDialog::OnColumnClick(wxListEvent &event)
{
    int max;
    if(m_select) max = 6;
    else max = 7;
    if(0 > event.GetColumn() || event.GetColumn() >= max) return;
    setColumnImage(m_sortCol, -1);
    m_sortCol = event.GetColumn();
    m_sortAsc = !m_sortAsc;
    setColumnImage(m_sortCol, m_sortAsc?2:3);
    fillList();
}

void DphDruhyDialog::setColumnImage(int column, int image)
{
    wxListItem item;
    item.SetMask(wxLIST_MASK_IMAGE);
    item.SetImage(image);
    m_list->SetColumn(column, item);
}

void DphDruhyDialog::getData()
{
    if(!m_filter)
    {
        switch(m_type)
        {
            case DD_ALL: m_dphdruhy = idbmodel->dphdruhy(); break;
            case DD_PRIJEM: m_dphdruhy = idbmodel->dphdruhyNabizenePrijem(); break;
            case DD_VYDAJ: m_dphdruhy = idbmodel->dphdruhyNabizeneVydaj(); break;
        }
    }
    else
    {
        m_dphdruhy.Clear();
        dxDphDruhArray dphdruhy = idbmodel->dphdruhy();
        for(size_t i=0; i<dphdruhy.GetCount(); i++)
        {
            if(m_filters[0].matchFilter(dphdruhy[i].zkratka()) && m_filters[1].matchFilter(dphdruhy[i].popis()) && m_filters[2].matchFilter(dphdruhy[i].plneni())
                    && m_filters[3].matchFilter(dphdruhy[i].radky()) && m_filters[4].matchFilter(dphdruhy[i].kpp().IsEmpty()?wxString::FromUTF8("Prázdné"):dphdruhy[i].kpp())
                    && m_filters[5].matchFilter(dphdruhy[i].kh().IsEmpty()?wxString::FromUTF8("Nepoužito"):dphdruhy[i].kh())
                    && m_filters[6].matchFilter(dphdruhy[i].nabizet()))
            {
                m_dphdruhy.Add(dphdruhy[i]);
            }
        }
    }
}

void DphDruhyDialog::OnFilter(wxCommandEvent &/*event*/)
{
    DphDruhFilter filter(this,m_filters);
    if(filter.ShowModal() == wxID_OK)
    {
        m_filters = filter.filters();
        m_filter = false;
        for(size_t i=0; i<m_filters.GetCount(); i++)
        {
            if(m_filters[i].active())
            {
                m_filter = true;
                break;
            }
        }
        m_bar->ToggleTool(ID_DPHDRUHY_FILTER, m_filter);
        m_bar->EnableTool(ID_DPHDRUHY_FILTERCLEAR, m_filter);
        if(m_list->GetColumnCount() == static_cast<long>(m_filters.GetCount()))
        {
            for(size_t i=0; i<m_filters.GetCount(); i++)
            {
                m_list->SetColumnHeaderFiltered(i, m_filters[i].active());
            }
            m_list->Update();
        }
    }
    else
    {
        m_filter = false;
        m_bar->ToggleTool(ID_DPHDRUHY_FILTER, false);
        m_bar->EnableTool(ID_DPHDRUHY_FILTERCLEAR, false);
        for(int i=0; i<m_list->GetColumnCount(); i++)
        {
            m_list->SetColumnHeaderFiltered(i, false);
        }
        m_list->Update();
    }
    fillList();
}

void DphDruhyDialog::OnFilterClear(wxCommandEvent &/*event*/)
{
    m_bar->ToggleTool(ID_DPHDRUHY_FILTER, false);
    m_filter = false;
    m_bar->EnableTool(ID_DPHDRUHY_FILTERCLEAR, false);
    for(int i=0; i<m_list->GetColumnCount(); i++)
    {
        m_list->SetColumnHeaderFiltered(i, false);
    }
    m_list->Update();
    fillList();
}

long DphDruhyDialog::selectedID() const
{
    return m_selectedId;
}

==> dxde_1.40.12-1.tar.gz: BUILD/src/gui/dialogs/dphdruhydialog.cpp <==
/***************************************************************
 * Name:      dphdruhydialog.cpp
 * Author:    David Vachulka (archdvx@dxsolutions.org)
 * Copyright: 2015
 * License:   GPL3
 **************************************************************/

#include "dphdruhydialog.h"
#include "dxdefs.h"
#include "utils/dxutils.h"
#include "utils/dxsettings.h"
#include "resources/images/checked.xpm"
#include "resources/images/unchecked.xpm"
#include "resources/images/asc.xpm"
#include "resources/images/desc.xpm"
#include "resources/images/filter.xpm"
#include "resources/images/filter_clear.xpm"

IMPLEMENT_DYNAMIC_CLASS(DphDruhyDialog, wxDialog)

BEGIN_EVENT_TABLE(DphDruhyDialog, wxDialog)
    EVT_BUTTON(wxID_OK, DphDruhyDialog::OnOk)
    EVT_BUTTON(wxID_CANCEL, DphDruhyDialog::OnCancel)
    EVT_LIST_ITEM_RIGHT_CLICK(ID_DPHDRUHY_LIST, DphDruhyDialog::OnItemRightClick)
    EVT_LIST_ITEM_ACTIVATED(ID_DPHDRUHY_LIST, DphDruhyDialog::OnItemActivated)
    EVT_LIST_ITEM_SELECTED(ID_DPHDRUHY_LIST, DphDruhyDialog::OnItemSelected)
    EVT_LIST_ITEM_DESELECTED(ID_DPHDRUHY_LIST, DphDruhyDialog::OnItemDeselected)
    EVT_LIST_COL_CLICK(ID_DPHDRUHY_LIST, DphDruhyDialog::OnColumnClick)
    EVT_MENU(ID_DPHDRUHY_ENABLE, DphDruhyDialog::OnEnableDphDruh)
    EVT_MENU(ID_DPHDRUHY_FILTER, DphDruhyDialog::OnFilter)
    EVT_MENU(ID_DPHDRUHY_FILTERCLEAR, DphDruhyDialog::OnFilterClear)
END_EVENT_TABLE()

DphDruhyDialog::DphDruhyDialog(wxWindow *parent, bool select, DType type, const wxDateTime &datum)
    : wxDialog(parent, wxID_ANY, wxString::FromUTF8("Členění DPH")),
      m_select(select), m_type(type), m_selectedId(-1), m_sortCol(0), m_sortAsc(true), m_filter(false)
{
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, 0));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, 1));

    if(select) m_datum = datum;
    else m_datum = dxsettings.datum();

    m_mainSizer = new wxBoxSizer(wxVERTICAL);
    if(!m_select)
    {
        m_bar = new dxToolBar(this);
        m_bar->AddTool(ID_DPHDRUHY_FILTER, wxEmptyString, wxBitmap(filter_xpm), dxutils::GreyScaledIcon(filter_xpm), wxITEM_CHECK, "Filtrovat");
        m_bar->AddTool(ID_DPHDRUHY_FILTERCLEAR, wxEmptyString, wxBitmap(filter_clear_xpm), dxutils::GreyScaledIcon(filter_clear_xpm), wxITEM_NORMAL, wxString::FromUTF8("Zrušit filtr"));
        m_bar->Realize();
        m_bar->EnableTool(ID_DPHDRUHY_FILTERCLEAR, false);
        m_mainSizer->Add(m_bar, 0, wxALL|wxEXPAND, 5);
    }
    wxSize imageSize(16, 16);
    m_imageList.reset(new wxImageList(imageSize.GetWidth(), imageSize.GetHeight()));
    m_imageList->Add(wxImage(checked_xpm).Scale(16, 16));
    m_imageList->Add(wxImage(unchecked_xpm).Scale(16, 16));
    m_imageList->Add(wxImage(asc_xpm).Scale(16, 16));
    m_imageList->Add(wxImage(desc_xpm).Scale(16, 16));
    m_list = new dxListCtrl(this, ID_DPHDRUHY_LIST, false);
    m_list->SetImageList(m_imageList.get(), wxIMAGE_LIST_SMALL);
    wxListItem col0;
    col0.SetId(0);
    col0.SetText("Zkratka");
    col0.SetWidth(65);
    m_list->InsertColumn(0, col0);
    wxListItem col1;
    col1.SetId(1);
    col1.SetText("Popis");
    col1.SetWidth(350);
    m_list->InsertColumn(1, col1);
    wxListItem col2;
    col2.SetId(2);
    col2.SetText(wxString::FromUTF8("Plnění"));
    col2.SetWidth(100);
    m_list->InsertColumn(2, col2);
    wxListItem col3;
    col3.SetId(3);
    col3.SetText(wxString::FromUTF8("Řádky v přiznání"));
    col3.SetWidth(115);
    m_list->InsertColumn(3, col3);
    wxListItem col4;
    col4.SetId(4);
    col4.SetText(wxString::FromUTF8("Předmět plnění"));
    col4.SetWidth(110);
    m_list->InsertColumn(4, col4);
    wxListItem col5;
    col5.SetId(5);
    col5.SetText(wxString::FromUTF8("Oddíl v KH"));
    col5.SetWidth(115);
    m_list->InsertColumn(5, col5);
    if(!m_select)
    {
        wxListItem col6;
        col6.SetId(6);
        col6.SetText(wxString::FromUTF8("Nabízet"));
        col6.SetWidth(80);
        m_list->InsertColumn(6, col6);
    }
    m_list->setResizeColumn(2);
    m_list->setResizeColumnMinWidth(100);
    fillList();
    m_mainSizer->Add(m_list, 1, wxALL|wxEXPAND, 5);
    wxStdDialogButtonSizer *btnSizer = new wxStdDialogButtonSizer();
    wxButton* okButton = new wxButton(this, wxID_OK, select? "&Vybrat" : "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(okButton);
    wxButton* cancelButton = new wxButton(this, wxID_CANCEL, "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(cancelButton);
    btnSizer->Realize();
    m_mainSizer->Add(btnSizer, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 5);
    this->SetSizer(m_mainSizer);
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

void DphDruhyDialog::OnOk(wxCommandEvent& /*event*/)
{
    EndModal(wxID_OK);
}

void DphDruhyDialog::OnCancel(wxCommandEvent& /*event*/)
{
    EndModal(wxID_CANCEL);
}

void DphDruhyDialog::OnItemRightClick(wxListEvent &event)
{
    setSelectedId(event.GetIndex());
    if(m_selectedId != -1)
    {
        wxMenu popup;
        popup.Append(ID_DPHDRUHY_ENABLE, m_dphdruhy[event.GetIndex()].nabizet()?wxString::FromUTF8("Nenabízet členění DPH"):wxString::FromUTF8("Nabízet členění DPH"));
        PopupMenu(&popup, event.GetPoint()+m_list->GetPosition());
    }
}

void DphDruhyDialog::OnItemActivated(wxListEvent &event)
{
    setSelectedId(event.GetIndex());
    if(m_select)
    {
        EndModal(wxID_OK);
    }
}

void DphDruhyDialog::OnItemSelected(wxListEvent &event)
{
    setSelectedId(event.GetIndex());
}

void DphDruhyDialog::OnItemDeselected(wxListEvent& /*event*/)
{
    setSelectedId(-1);
}

void DphDruhyDialog::setSelectedId(long selectedIndex)
{
    if(selectedIndex < 0)
        m_selectedId = -1;
    else
        m_selectedId = m_dphdruhy[selectedIndex].id();
}

void DphDruhyDialog::OnEnableDphDruh(wxCommandEvent& /*event*/)
{
    if(m_selectedId == -1) return;
    idbmodel->nabizetDphDruh(m_selectedId);
    fillList();
}

void DphDruhyDialog::fillList()
{
    m_list->DeleteAllItems();
    m_list->Hide();
    getData();
    idbmodel->sortDphDruh(m_dphdruhy, m_sortCol, m_sortAsc);
    long id = 0;
    for(size_t i=0; i < m_dphdruhy.GetCount(); i++)
    {
        if(!m_datum.IsBetween(m_dphdruhy[i].validFrom(), m_dphdruhy[i].validTo())) continue;
        wxListItem item;
        item.SetId(id);
        item.SetText(m_dphdruhy[i].zkratka());
        item.SetImage(-1);
        m_list->InsertItem(item);
        m_list->SetItem(id, 1, m_dphdruhy[i].popis());
        m_list->SetItem(id, 2, m_dphdruhy[i].plneni()?wxString::FromUTF8("Přijaté"):wxString::FromUTF8("Uskutečněné"));
        m_list->SetItem(id, 3, m_dphdruhy[i].radky());
        m_list->SetItem(id, 4, m_dphdruhy[i].kpp());
        m_list->SetItem(id, 5, m_dphdruhy[i].kh());
        if(!m_select) m_list->SetItem(id, 6, wxEmptyString, m_dphdruhy[i].nabizet()?0:1);
        id++;
    }
    m_list->Show();
    if(m_select && m_dphdruhy.GetCount())
        m_list->SetItemState(0, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
    else
        setSelectedId(-1);
    setColumnImage(m_sortCol, m_sortAsc?2:3);
}

void DphDruhyDialog::OnColumnClick(wxListEvent &event)
{
    int max;
    if(m_select) max = 6;
    else max = 7;
    if(0 > event.GetColumn() || event.GetColumn() >= max) return;
    setColumnImage(m_sortCol, -1);
    m_sortCol = event.GetColumn();
    m_sortAsc = !m_sortAsc;
    setColumnImage(m_sortCol, m_sortAsc?2:3);
    fillList();
}

void DphDruhyDialog::setColumnImage(int column, int image)
{
    wxListItem item;
    item.SetMask(wxLIST_MASK_IMAGE);
    item.SetImage(image);
    m_list->SetColumn(column, item);
}

void DphDruhyDialog::getData()
{
    if(!m_filter)
    {
        switch(m_type)
        {
            case DD_ALL: m_dphdruhy = idbmodel->dphdruhy(); break;
            case DD_PRIJEM: m_dphdruhy = idbmodel->dphdruhyNabizenePrijem(); break;
            case DD_VYDAJ: m_dphdruhy = idbmodel->dphdruhyNabizeneVydaj(); break;
        }
    }
    else
    {
        m_dphdruhy.Clear();
        dxDphDruhArray dphdruhy = idbmodel->dphdruhy();
        for(size_t i=0; i<dphdruhy.GetCount(); i++)
        {
            if(m_filters[0].matchFilter(dphdruhy[i].zkratka()) && m_filters[1].matchFilter(dphdruhy[i].popis()) && m_filters[2].matchFilter(dphdruhy[i].plneni())
                    && m_filters[3].matchFilter(dphdruhy[i].radky()) && m_filters[4].matchFilter(dphdruhy[i].kpp().IsEmpty()?wxString::FromUTF8("Prázdné"):dphdruhy[i].kpp())
                    && m_filters[5].matchFilter(dphdruhy[i].kh().IsEmpty()?wxString::FromUTF8("Nepoužito"):dphdruhy[i].kh())
                    && m_filters[6].matchFilter(dphdruhy[i].nabizet()))
            {
                m_dphdruhy.Add(dphdruhy[i]);
            }
        }
    }
}

void DphDruhyDialog::OnFilter(wxCommandEvent &/*event*/)
{
    DphDruhFilter filter(this,m_filters);
    if(filter.ShowModal() == wxID_OK)
    {
        m_filters = filter.filters();
        m_filter = false;
        for(size_t i=0; i<m_filters.GetCount(); i++)
        {
            if(m_filters[i].active())
            {
                m_filter = true;
                break;
            }
        }
        m_bar->ToggleTool(ID_DPHDRUHY_FILTER, m_filter);
        m_bar->EnableTool(ID_DPHDRUHY_FILTERCLEAR, m_filter);
        if(m_list->GetColumnCount() == static_cast<long>(m_filters.GetCount()))
        {
            for(size_t i=0; i<m_filters.GetCount(); i++)
            {
                m_list->SetColumnHeaderFiltered(i, m_filters[i].active());
            }
            m_list->Update();
        }
    }
    else
    {
        m_filter = false;
        m_bar->ToggleTool(ID_DPHDRUHY_FILTER, false);
        m_bar->EnableTool(ID_DPHDRUHY_FILTERCLEAR, false);
        for(int i=0; i<m_list->GetColumnCount(); i++)
        {
            m_list->SetColumnHeaderFiltered(i, false);
        }
        m_list->Update();
    }
    fillList();
}

void DphDruhyDialog::OnFilterClear(wxCommandEvent &/*event*/)
{
    m_bar->ToggleTool(ID_DPHDRUHY_FILTER, false);
    m_filter = false;
    m_bar->EnableTool(ID_DPHDRUHY_FILTERCLEAR, false);
    for(int i=0; i<m_list->GetColumnCount(); i++)
    {
        m_list->SetColumnHeaderFiltered(i, false);
    }
    m_list->Update();
    fillList();
}

long DphDruhyDialog::selectedID() const
{
    return m_selectedId;
}
